@@ -345,8 +345,6 @@ QString Utils::appTypeToI18n(AppsType type)
         return i18n("KNotes");
     case Akregator:
         return i18n("Akregator");
-    case Blogilo:
-        return i18n("Blogilo");
     case Unknown:
         break;
     }
