@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2015-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,7 +27,7 @@ class ImportExportProgressIndicatorGui : public ImportExportProgressIndicatorBas
     Q_OBJECT
 public:
     explicit ImportExportProgressIndicatorGui(QWidget *parentWidget, QObject *parent = nullptr);
-    ~ImportExportProgressIndicatorGui();
+    ~ImportExportProgressIndicatorGui() override;
 
     void increaseProgressDialog() override;
     void createProgressDialog(const QString &title) override;
